@@ -5,6 +5,7 @@ var vsttypes_8h =
     [ "kVstVersionMinor", "vsttypes_8h.html#aad745365073e680343605ac17c381811", null ],
     [ "kVstVersionSub", "vsttypes_8h.html#a6e91d244c8cfdd2b123d37e599043ca1", null ],
     [ "VST_VERSION", "vsttypes_8h.html#a8f8e3e0f6ff1889cda8597884edccb61", null ],
+    [ "VST_3_7_12_VERSION", "vsttypes_8h.html#a79417033b8926d7da1e79f901ed7b739", null ],
     [ "VST_3_7_11_VERSION", "vsttypes_8h.html#a81da5801773d5e380b67d049650b72b4", null ],
     [ "VST_3_7_10_VERSION", "vsttypes_8h.html#adc77fadc46f7777596d41e72746f2f93", null ],
     [ "VST_3_7_9_VERSION", "vsttypes_8h.html#a100b1e2c5665d6ea27ec0282bf555f7f", null ],
@@ -31,24 +32,24 @@ var vsttypes_8h =
     [ "VST_3_5_0_VERSION", "vsttypes_8h.html#aba0780a21f237667b79111c8f7419c79", null ],
     [ "VST_3_1_0_VERSION", "vsttypes_8h.html#a4b747744c89f19d7c063f1823d533a5d", null ],
     [ "VST_3_0_0_VERSION", "vsttypes_8h.html#a6c479776692cf749f41bd7bbcb0b79cd", null ],
-    [ "TChar", "vsttypes_8h.html#ga9cc7040d53a88b14ecab90ffb052276d", null ],
-    [ "String128", "vsttypes_8h.html#ga4b750afeaca8056101ac7952543dfd47", null ],
-    [ "CString", "vsttypes_8h.html#gaf857b729bfca1b912196dd4ff5421420", null ],
-    [ "MediaType", "vsttypes_8h.html#ga5f0d28213b308d786ef7a1541d88368f", null ],
-    [ "BusDirection", "vsttypes_8h.html#ga0dc035dac7916366d61df365731f7b63", null ],
-    [ "BusType", "vsttypes_8h.html#gaa6029db01759d30cfcb3504b84d5d04f", null ],
-    [ "IoMode", "vsttypes_8h.html#ga479361a38cb42c6a07bc6845a5801e55", null ],
-    [ "UnitID", "vsttypes_8h.html#ga6569c340fc68115670ee0161dd73b3ed", null ],
-    [ "ParamValue", "vsttypes_8h.html#ga11508dccaa352a24d0ae6585a93f4641", null ],
-    [ "ParamID", "vsttypes_8h.html#ga1dac5893f4a5c27f986d4e51741b544c", null ],
-    [ "ProgramListID", "vsttypes_8h.html#gaac31a9d9a63927ad6927f2a298888c22", null ],
-    [ "CtrlNumber", "vsttypes_8h.html#gaa67d0906fec66282a0c9488cb52162f6", null ],
-    [ "TQuarterNotes", "vsttypes_8h.html#gabf70aac64179b2b47bd877600a2e8c28", null ],
-    [ "TSamples", "vsttypes_8h.html#gad2e841097395dbff119029f4684dad8f", null ],
-    [ "ColorSpec", "vsttypes_8h.html#ga5b13d028fba1eee386ec9ac208c6238d", null ],
-    [ "Sample32", "vsttypes_8h.html#ga353ad4086d31e4b7c57c9124965379a6", null ],
-    [ "Sample64", "vsttypes_8h.html#ga8887669e1feb9270b120bcd725d0d4c1", null ],
-    [ "SampleRate", "vsttypes_8h.html#ga11249ca544d179e7fa61b2200a092407", null ],
-    [ "SpeakerArrangement", "vsttypes_8h.html#ga54884a26d0b6dfa18eb919ea004775ac", null ],
-    [ "Speaker", "vsttypes_8h.html#ga7a9fc6561fe897989fa3cea09ebb3250", null ]
+    [ "TChar", "vsttypes_8h.html#a9cc7040d53a88b14ecab90ffb052276d", null ],
+    [ "String128", "vsttypes_8h.html#a4b750afeaca8056101ac7952543dfd47", null ],
+    [ "CString", "vsttypes_8h.html#af857b729bfca1b912196dd4ff5421420", null ],
+    [ "MediaType", "vsttypes_8h.html#a5f0d28213b308d786ef7a1541d88368f", null ],
+    [ "BusDirection", "vsttypes_8h.html#a0dc035dac7916366d61df365731f7b63", null ],
+    [ "BusType", "vsttypes_8h.html#aa6029db01759d30cfcb3504b84d5d04f", null ],
+    [ "IoMode", "vsttypes_8h.html#a479361a38cb42c6a07bc6845a5801e55", null ],
+    [ "UnitID", "vsttypes_8h.html#a6569c340fc68115670ee0161dd73b3ed", null ],
+    [ "ParamValue", "vsttypes_8h.html#a11508dccaa352a24d0ae6585a93f4641", null ],
+    [ "ParamID", "vsttypes_8h.html#a1dac5893f4a5c27f986d4e51741b544c", null ],
+    [ "ProgramListID", "vsttypes_8h.html#aac31a9d9a63927ad6927f2a298888c22", null ],
+    [ "CtrlNumber", "vsttypes_8h.html#aa67d0906fec66282a0c9488cb52162f6", null ],
+    [ "TQuarterNotes", "vsttypes_8h.html#abf70aac64179b2b47bd877600a2e8c28", null ],
+    [ "TSamples", "vsttypes_8h.html#ad2e841097395dbff119029f4684dad8f", null ],
+    [ "ColorSpec", "vsttypes_8h.html#a5b13d028fba1eee386ec9ac208c6238d", null ],
+    [ "Sample32", "vsttypes_8h.html#a353ad4086d31e4b7c57c9124965379a6", null ],
+    [ "Sample64", "vsttypes_8h.html#a8887669e1feb9270b120bcd725d0d4c1", null ],
+    [ "SampleRate", "vsttypes_8h.html#a11249ca544d179e7fa61b2200a092407", null ],
+    [ "SpeakerArrangement", "vsttypes_8h.html#a54884a26d0b6dfa18eb919ea004775ac", null ],
+    [ "Speaker", "vsttypes_8h.html#a7a9fc6561fe897989fa3cea09ebb3250", null ]
 ];
\ No newline at end of file
